aboutsummaryrefslogtreecommitdiff
path: root/src/google_breakpad/processor/symbol_supplier.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/google_breakpad/processor/symbol_supplier.h')
-rw-r--r--src/google_breakpad/processor/symbol_supplier.h16
1 files changed, 13 insertions, 3 deletions
diff --git a/src/google_breakpad/processor/symbol_supplier.h b/src/google_breakpad/processor/symbol_supplier.h
index 0459c8aa..752bbbc3 100644
--- a/src/google_breakpad/processor/symbol_supplier.h
+++ b/src/google_breakpad/processor/symbol_supplier.h
@@ -59,12 +59,22 @@ class SymbolSupplier {
// Retrieves the symbol file for the given CodeModule, placing the
// path in symbol_file if successful. system_info contains strings
// identifying the operating system and CPU; SymbolSupplier may use to help
// locate the symbol file. system_info may be NULL or its fields may be
// empty if these values are unknown.
virtual SymbolResult GetSymbolFile(const CodeModule *module,
const SystemInfo *system_info,
string *symbol_file) = 0;
+ // Same as above, except also places symbol data into symbol_data.
+ // If symbol_data is NULL, the data is not returned.
+ // TODO(nealsid) Once we have symbol data caching behavior implemented
+ // investigate making all symbol suppliers implement all methods,
+ // and make this pure virtual
+ virtual SymbolResult GetSymbolFile(const CodeModule *module,
+ const SystemInfo *system_info,
+ string *symbol_file,
+ string *symbol_data) { assert(0); }
};
} // namespace google_breakpad
@@ -59,12 +59,22 @@ class SymbolSupplier {
// Retrieves the symbol file for the given CodeModule, placing the
// path in symbol_file if successful. system_info contains strings
- // identifying the operating system and CPU; SymbolSupplier may use to help
- // locate the symbol file. system_info may be NULL or its fields may be
- // empty if these values are unknown.
+ // identifying the operating system and CPU; SymbolSupplier may use
+ // to help locate the symbol file. system_info may be NULL or its
+ // fields may be empty if these values are unknown. symbol_file
+ // must be a pointer to a valid string
virtual SymbolResult GetSymbolFile(const CodeModule *module,
const SystemInfo *system_info,